var indexSectionsWithContent =
{
  0: "abcdefghijklmnopqrstuvwy~",
  1: "b",
  2: "b",
  3: "abcdefgilmnopqrstuv~",
  4: "abcdefgijklmnoprstu",
  5: "b",
  6: "be",
  7: "b",
  8: "bcdefhlmort"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "files",
  3: "functions",
  4: "variables",
  5: "enums",
  6: "enumvalues",
  7: "defines",
  8: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Files",
  3: "Functions",
  4: "Variables",
  5: "Enumerations",
  6: "Enumerator",
  7: "Macros",
  8: "Pages"
};

